@@ -399,7 +399,7 @@ class Linkgrabber:
         """
         resp = self.device.action("/linkgrabberv2/addLinks", params)
         return resp
-    
+
     def is_collecting(self):
         """
         Boolean status query about the collecting process
@@ -435,12 +435,13 @@ class Linkgrabber:
         resp = self.device.action("/linkgrabberv2/help", http_action="GET")
         return resp
 
-    def rename_link(self):
+    def rename_link(self, link_id, new_name):
         """
-        No idea what parameters i have to pass and/or i don't know what it does.
-        If i find out i will implement it :P
+        Renames files related with link_id
         """
-        pass
+        params = [link_id, new_name]
+        resp = self.device.action(self.url + "/renameLink", params)
+        return resp
 
     def move_links(self):
         """
@@ -632,6 +633,12 @@ class Downloads:
         resp = self.device.action(self.url + "/forceDownload", params)
         return resp
 
+    def set_dl_location(self, directory, package_ids=[]):
+        params = [directory, package_ids]
+        resp = self.device.action(self.url + "/setDownloadDirectory", params)
+        return resp
+
+
 class Captcha:
     """
     Class that represents the captcha interface of a Device
@@ -745,8 +752,9 @@ class Jddevice:
             response = self.myjd.request_api(path, http_action, params,
                                              action_url)
             if response is None:
-                # My.JDownloader Api failed too.
-                return False
+                # My.JDownloader Api failed too we assume a problem with the connection or the api server
+                # and throw an connection exception.
+                raise (MYJDConnectionException("No connection established\n"))
             else:
                 # My.JDownloader Api worked, lets refresh the direct connections and return
                 # the response.
@@ -781,8 +789,9 @@ class Jddevice:
             response = self.myjd.request_api(path, http_action, params,
                                              action_url)
             if response is None:
-                # My.JDownloader Api failed too.
-                return False
+                # My.JDownloader Api failed too we assume a problem with the connection or the api server
+                # and throw an connection exception.
+                raise (MYJDConnectionException("No connection established\n"))
             # My.JDownloader Api worked, lets refresh the direct connections and return
             # the response.
             self.__refresh_direct_connections()
